@@ -15,16 +15,16 @@
 // #include <tqlayout.h>
 // 
 // // KDE includes
-// #include <kglobal.h>
-// #include <klocale.h>
-// #include <kaboutdata.h>
-// #include <kconfig.h>
-// #include <kapplication.h>
-// #include <kmessagebox.h>
-// #include <kapplication.h>
-// #include <kmessagebox.h>
+// #include <tdeglobal.h>
+// #include <tdelocale.h>
+// #include <tdeaboutdata.h>
+// #include <tdeconfig.h>
+// #include <tdeapplication.h>
+// #include <tdemessagebox.h>
+// #include <tdeapplication.h>
+// #include <tdemessagebox.h>
 // #include <dcopclient.h>
-// #include <kaboutapplication.h>
+// #include <tdeaboutapplication.h>
 
 
 /*
@@ -33,13 +33,13 @@
 #include "mainwidget.h"
 */
 
-MainApp::MainApp() : KApplication() {
+MainApp::MainApp() : TDEApplication() {
 
 
 	// Get the current application configuration handle
 //	KMessageBox::information( 0, i18n( "Starting Deamon" ) );
 
-//	KConfig *ksConfig = config();
+//	TDEConfig *ksConfig = config();
 //	KMFIPTWatcher *watch = new KMFIPTWatcher( this, "KMFIPTWatcher" );
 //	MainWidget *mainWid = new MainWidget( 0 );
 //	connect( watch, TQT_SIGNAL( sigUpdateActive( bool ) ), mainWid, TQT_SLOT( slotSetRunningStatus( bool ) ) );
