@@ -17,18 +17,18 @@ email                : chubinger@irrsinnig.org
 //KDE includes
 #include <kled.h>
 #include <kdebug.h>
-#include <klocale.h>
-#include <klistview.h>
-#include <kpopupmenu.h>
-#include <kmessagebox.h>
-#include <kapplication.h>
-#include <klistbox.h>
+#include <tdelocale.h>
+#include <tdelistview.h>
+#include <tdepopupmenu.h>
+#include <tdemessagebox.h>
+#include <tdeapplication.h>
+#include <tdelistbox.h>
 #include <kpushbutton.h>
 #include <kcombobox.h>
 #include <ktrader.h>
-#include <kparts/part.h>
-#include <kparts/plugin.h>
-#include <kparts/factory.h>
+#include <tdeparts/part.h>
+#include <tdeparts/plugin.h>
+#include <tdeparts/factory.h>
 
 //QT includes
 #include <tqtooltip.h>
@@ -171,7 +171,7 @@ KMFRuleEdit::KMFRuleEdit( TQWidget* parent, const char* name, WFlags fl )
 	m_myNetworkWidget->hide(); //close( false );
 
 	m_check_input = new KMFCheckInput();
-	m_contextMenu = new KPopupMenu( this );
+	m_contextMenu = new TDEPopupMenu( this );
 	
 	connect( cb_log_rule, TQT_SIGNAL( clicked() ),
 	         this, TQT_SLOT( slotLogRuleChanged() ) );
@@ -1182,7 +1182,7 @@ void KMFRuleEdit::createRBM( NetfilterObject* obj ) {
 			TQString lab_str = i18n("Rule: %1").arg( name );
 			m_contextMenu->insertTitle( icon_rule, lab_str );
 
-			KPopupMenu *sub_edit = new KPopupMenu( m_contextMenu );
+			TDEPopupMenu *sub_edit = new TDEPopupMenu( m_contextMenu );
 			sub_edit->insertTitle( i18n( "Edit Rule Option" ) );
 			for( uint i = 0; i < m_editPlugins.count(); i++ ) {
 				sub_edit->insertItem( icon_edit, i18n( "Edit %1" ).arg(m_editPlugins.at(i)->optionEditName() ), i );
@@ -1205,7 +1205,7 @@ void KMFRuleEdit::createRBM( NetfilterObject* obj ) {
 				m_contextMenu->insertItem( icon_del, i18n( "Delete Chain" ), this, TQT_SLOT( slotDelChain() ) );
 			m_contextMenu->insertSeparator();
 
-			KPopupMenu *sub_copy = new KPopupMenu( m_contextMenu );
+			TDEPopupMenu *sub_copy = new TDEPopupMenu( m_contextMenu );
 			connect( sub_copy, TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( slotCopyRule( int ) ) );
 			sub_copy->insertTitle( i18n( "Copy to Chain" ) );
 			TQPtrList<IPTChain> chains = m_table ->chains();
@@ -1215,7 +1215,7 @@ void KMFRuleEdit::createRBM( NetfilterObject* obj ) {
 			}
 			m_contextMenu->insertItem( icon_copy, i18n( "Copy Rule" ), sub_copy );
 
-			KPopupMenu *sub_move = new KPopupMenu( m_contextMenu );
+			TDEPopupMenu *sub_move = new TDEPopupMenu( m_contextMenu );
 			connect( sub_move, TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( slotMoveRule( int ) ) );
 			sub_move->insertTitle( i18n( "Move to Chain" ) );
 			TQPtrList<IPTChain> chains2 = m_table->chains();
@@ -1446,69 +1446,69 @@ void KMFRuleEdit::slotHelp() {
 }
 void KMFRuleEdit::loadIcons() {
 	kdDebug() << "void KMFRuleEdit::loadIcons()" << endl;
-	KIconLoader *loader = KGlobal:: iconLoader();
+	TDEIconLoader *loader = TDEGlobal:: iconLoader();
 	TQString icon_name;
 
-	icon_name = "up";
-	icon_up = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "go-up";
+	icon_up = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "down";
-	icon_down = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "go-down";
+	icon_down = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "editdelete";
-	icon_del = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-delete";
+	icon_del = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "filenew";
-	icon_new = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "document-new";
+	icon_new = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "edit";
-	icon_edit = loader->loadIcon( icon_name, KIcon::Small );
+	icon_edit = loader->loadIcon( icon_name, TDEIcon::Small );
 
 
 	icon_name = "filter";
-	icon_filter = loader->loadIcon( icon_name, KIcon::Small );
+	icon_filter = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "text";
-	icon_rename = loader->loadIcon( icon_name, KIcon::Small );
+	icon_rename = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "rule-22";
-	icon_rule = loader->loadIcon( icon_name, KIcon::Small );
+	icon_rule = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "view_tree";
-	icon_chain = loader->loadIcon( icon_name, KIcon::Small );
+	icon_chain = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "reject";
-	icon_reject = loader->loadIcon( icon_name, KIcon::User );
+	icon_reject = loader->loadIcon( icon_name, TDEIcon::User );
 
 	icon_name = "target";
-	icon_target = loader->loadIcon( icon_name, KIcon::User );
+	icon_target = loader->loadIcon( icon_name, TDEIcon::User );
 
-	icon_name = "stop";
-	icon_drop = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "process-stop";
+	icon_drop = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "button_ok";
-	icon_accept = loader->loadIcon( icon_name, KIcon::Small );
+	icon_accept = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "filesaveas";
-	icon_log = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "document-save-as";
+	icon_log = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "undo";
-	icon_return = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-undo";
+	icon_return = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "editclear";
-	icon_cmd = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-clear";
+	icon_cmd = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "filter";
-	icon_filter = loader->loadIcon( icon_name, KIcon::Small );
+	icon_filter = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "pipe";
-	icon_queue = loader->loadIcon( icon_name, KIcon::Small );
+	icon_queue = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "editcopy";
-	icon_copy = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-copy";
+	icon_copy = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "forward";
-	icon_move = loader->loadIcon( icon_name, KIcon::Small );
+	icon_move = loader->loadIcon( icon_name, TDEIcon::Small );
 
 }
 
